@@ -4,13 +4,13 @@
 #'
 #' @noRd
 appServer <- function(input, output, session) {
-  observeEvent(input$help, {
-    guide$init()$start()
-  })
+  setBookmarkExclude(c("remove_border", "remove_label", "remove_colour", "help", "css_style"))
+
+  observeEvent(input$help, guide$init()$start())
 
   page_html <- CanvasModuleServer("canvas")
 
-  SidebarModuleServer("sidebar")
+  SettingsModuleServer("settings", ui_code = page_html)
 
-  CodeModuleServer("settings-code", ui_code = page_html)
+  SidebarModuleServer("sidebar")
 }
